#!/usr/bin/env node

var fs = require('fs')

// portable file size
if (process.argv.length != 3) {
  process.stdout.write("usage: ./update.js <version>\n")
  process.stdout.write("update module to <version>\n")
  process.exit(0)
}

var version = process.argv[2]

// replace the version in README.md
var rFind = /ipfs version [0-9\.]+/g
var rRep = "ipfs version " + version
fsReplace("README.md", rFind, rRep)
console.log("updated README.md")

// replace the version in package.json
var pFind = /^  "version": "[^"]+",$/m
var pRep = '  "version": "'+ version +'",'
fsReplace("package.json", pFind, pRep)
console.log("updated package.json version")

// replace the go-ipfs-dep dependency in package.json
var pDepFind = /^    "go-ipfs-dep": "[^"]+",$/m
var pDepRep = '    "go-ipfs-dep": "'+ version +'",'
fsReplace("package.json", pDepFind, pDepRep)
console.log("updated package.json go-ipfs-dep")
console.log("WARNING: please make sure go-ipfs-dep version is correct.")
console.log("         use: npm view go-ipfs-dep versions")
console.log("         and verify the version is published")

function die(err) {
  process.stderr.write(err + "\n")
  process.exit(1)
}

function dieOnErr(err) {
  if (err) die(err)
}

function fsReplace(path, find, replace) {
  var contents = fs.readFileSync(path)
  contents = contents.toString()
  var nc = contents.replace(find, replace)
  var err = fs.writeFileSync(path, nc)

  if (err) {
    err = new Error("failed to write " + path + ": " + err)
    dieOnErr(err)
  }
}
